/**
 * @file printf_redirect.ino
 * @brief Example program demonstrating how to use the RedirectedSerial library.
 * 
 * This program shows how to redirect the `printf()` function's output to the Arduino Serial (USB) port
 * using the RedirectedSerial library. It prints a message every second to demonstrate the functionality.
 * 
 * @author István Cserny
 * @date 2025-02-14
 * @version 1.0.0
 * @license MIT
 * 
 * @note This example is designed for the Raspberry Pi Pico using the Arduino Mbed OS RP2040 core.
 * @see RedirectedSerial.h
 * 
 * Tested with:
 * - Arduino IDE v1.8.19
 * - Arduino Mbed OS RP2040 Core v4.2.1
 */

#include "RedirectedSerial.h"

void setup() {
    Serial.begin(115200);       // Initialize Serial (USB)
    delay(5000);
    printf("Redirecting printf to Serial\n");  // Print a startup message
}

void loop() {
    printf("Hello world!\n");  // Print a message every second
    delay(1000);
}
