/*
 * Ez a program az RP2040 egymagos üzemmódjában számolja ki 
 * Pi közelítő értékét, n = 1 000 000 iterációval
 * A program a Gregory-Leibniz sorozatot használja a Pi értékének 
 * kiszámításához, és méri a számítási időt (tipikusan 8118 ms)
 *
 * A program a következő lépéseket hajtja végre:
 * 1. Soros kommunikáció beállítása 115200 baud sebességgel.
 * 2. A számítási idő mérése a millis() függvénnyel.
 * 3. A Gregory-Leibniz sorozat felhasználásával számolja ki a pi értékét.
 * 4. A számítás végén kiírja a futási időt és a számított pi értékét.
 * 5. 2 másodperc szünetet tart, majd újraindítja a folyamatot.
 *
 * Tested with Arduino IDE 1.8.19 and MbedOS RP204 Boards v4.2.1
 */

#include <Arduino.h>

void setup() {
  Serial.begin(115200);
}

void loop() {
  // Kezdjük el mérni az időt
  Serial.println("Kezdjük a számolást");
  unsigned long start_time = millis();

  // Hosszú számolás (Gregory-Leibniz sorozat)
  volatile double pi = 0.0;
  unsigned long n = 1000000; // Iterációk száma
  for (unsigned long i = 0; i < n; ++i) {
    if (i % 2 == 0) {
      pi += 1.0 / (2 * i + 1);
    } else {
      pi -= 1.0 / (2 * i + 1);
    }
  }
  pi *= 4; // Gregory-Leibniz sorozat végén meg kell szorozni 4-gyel

  // Mérések befejezése
  unsigned long end_time = millis();
  unsigned long execution_time = end_time - start_time;

  // Kiírjuk a futási időt
  Serial.print("Futási idő: ");
  Serial.print(execution_time);
  Serial.println(" ms");

  // Kiírjuk a számított pi értéket (csak ellenőrzésképpen)
  Serial.print("Számított pi érték: ");
  Serial.println(pi, 10); // 10 tizedesjegyig pontos

  // 2 másodperc szünet
  delay(2000);
}
